@@ -67,7 +67,7 @@ public:
 	static volatile int count;
 };
 
-myTCPSocket::myTCPSocket(InetAddress &ia) : TCPSocket(ia, 4096) {};
+myTCPSocket::myTCPSocket(InetAddress &ia) : TCPSocket(ia, 4096) {}
 
 bool myTCPSocket::onAccept(const InetHostAddress &ia, tpport_t port)
 {
@@ -103,7 +103,6 @@ void myTCPSession::run(void)
 
 void myTCPSession::final(void)
 {
-	delete this;
 }
 
 int main()
