@@ -60,17 +60,22 @@
 #endif
 
 #ifndef WIN32
-#ifdef	__BORLANDC__
-#include <stdio.h>
-#include <sys/types.h>
+# ifdef __BORLANDC__
+#  include <stdio.h>
+#  include <sys/types.h>
+# else
+#  include <cstdio>
+# endif
+# include <dirent.h>
+# include <sys/stat.h>
+# include <sys/mman.h>
 #else
-#include <cstdio>
-#endif
-#include <dirent.h>
-#include <sys/stat.h>
-#include <sys/mman.h>
-#else
-#include <direct.h>
+# if __BORLANDC__ >= 0x0560
+#  include <dirent.h>
+#  include <sys/stat.h>
+# else
+#  include <direct.h>
+# endif
 #endif
 
 #ifdef	HAVE_SHL_LOAD
@@ -93,7 +98,7 @@ typedef	unsigned long pos_t;
 #define	caddr_t	char *
 typedef size_t ccxx_size_t;
 #else
-#ifndef	__BORLANDC__
+#if	!defined(__BORLANDC__) || __BORLANDC__ >= 0x0560
 typedef LONG off_t;
 #endif
 typedef void* caddr_t;
