@@ -1783,7 +1783,7 @@ class __EXPORT SimpleTCPStream;
  * @date   2002-08-15
  * Copyright (C) 2002 Wizzer Works.
  **/
-class __EXPORT SimpleTCPStream : protected Socket
+class __EXPORT SimpleTCPStream : public Socket
 {
 private:
 
