@@ -43,14 +43,12 @@
 #ifndef	CCXX_THREAD_H_
 #define	CCXX_THREAD_H_
 
+#include <cc++/config.h>
+
 #ifndef WIN32
 #define	CCXX_POSIX
 #endif // !WIN32
 
-#ifndef CCXX_CONFIG_H_
-#include <cc++/config.h>
-#endif
-
 #include <ctime>
 
 #ifndef	WIN32
@@ -90,6 +88,10 @@ typedef DWORD   timeout_t;
 
 #ifdef	CCXX_NAMESPACES
 namespace ost {
+# if __BORLANDC__ >= 0x0560
+using std::time_t;
+using std::tm;
+# endif
 #endif
 
 #ifdef	HAVE_GCC_CXX_BITS_ATOMIC
